Extension

Struct Extension 

pub struct Extension { /* private fields */ }

Implementations

Source

impl Extension

pub fn apis(&self) -> Array<BnString>

String indicating the API used by the plugin

pub fn author(&self) -> String

String of the plugin author

pub fn description(&self) -> String

String short description of the plugin

pub fn license_text(&self) -> String

String complete license text for the given plugin

pub fn minimum_version_info(&self) -> VersionInfo

Minimum version info the plugin was tested on

pub fn maximum_version_info(&self) -> VersionInfo

Maximum version info the plugin will support

pub fn versions(&self) -> Array<ExtensionVersion>

Metadata for all available versions of this plugin

pub fn current_version(&self) -> ExtensionVersion

Metadata for the currently selected version of this plugin

pub fn name(&self) -> String

String plugin name

pub fn project_url(&self) -> String

String URL of the plugin’s git repository

pub fn package_url(&self) -> String

String URL of the plugin’s git repository

pub fn is_paid(&self) -> bool

Boolean True if this plugin requires payment, False otherwise

pub fn author_url(&self) -> String

String URL of the plugin author’s url

pub fn commit(&self) -> String

String of the commit of this plugin git repository

pub fn path(&self) -> PathBuf

Relative path from the base of the repository to the actual plugin

pub fn subdir(&self) -> PathBuf

Optional sub-directory the plugin code lives in as a relative path from the plugin root

pub fn dependencies(&self) -> String

Dependencies required for installing this plugin

pub fn is_installed(&self) -> bool

true if the plugin is installed, false otherwise

pub fn is_enabled(&self) -> bool

true if the plugin is enabled, false otherwise

pub fn status(&self) -> PluginStatus

pub fn types(&self) -> Array<PluginType>

List of PluginType enumeration objects indicating the plugin type(s)

pub fn enable(&self, force: bool) -> bool

Enable this plugin, optionally trying to force it. Force loading a plugin with ignore platform and api constraints.

pub fn disable(&self) -> bool

pub fn install(&self, version_id: &str) -> bool

Attempt to install the given plugin

pub fn install_dependencies(&self) -> bool

pub fn uninstall(&self) -> bool

Attempt to uninstall the given plugin

pub fn updated(&self, version_id: &str) -> bool

pub fn platforms(&self) -> Array<BnString>

List of platforms this plugin can execute on

pub fn repository(&self) -> String

pub fn is_being_deleted(&self) -> bool

Boolean status indicating that the plugin is being deleted

pub fn is_being_updated(&self) -> bool

Boolean status indicating that the plugin is being updated

pub fn is_running(&self) -> bool

Boolean status indicating that the plugin is currently running

pub fn is_update_pending(&self) -> bool

Boolean status indicating that the plugin has updates will be installed after the next restart

pub fn is_disable_pending(&self) -> bool

Boolean status indicating that the plugin will be disabled after the next restart

pub fn is_delete_pending(&self) -> bool

Boolean status indicating that the plugin will be deleted after the next restart

pub fn is_updated_available(&self) -> bool

Boolean status indicating that the plugin has updates available

pub fn are_dependencies_being_installed(&self) -> bool

Boolean status indicating that the plugin’s dependencies are currently being installed

pub fn project_data(&self) -> String

Gets a json object of the project data field